@@ -1,20 +1,14 @@
-# -*- coding: utf-8 -*-
-
-
 class TrailblazerError(Exception):
     def __init__(self, message):
         self.message = message
 
+    def __str__(self):
+        return f"TrailblazerError: {self.message}"
+
 
 class MissingFileError(TrailblazerError):
     pass
 
 
-class MipStartError(TrailblazerError):
+class EmptySqueueError(TrailblazerError):
     pass
-
-
-class ConfigError(TrailblazerError):
-    def __init__(self, message, errors=None):
-        self.message = message
-        self.errors = errors
